<?php
/**
 * Form for creating / updating a product.
 *
 * @package get-affiliate-link
 */

if ( ! defined( 'ABSPATH' ) ) { exit; } ?>

<div class="container" id="gal_price_table_no_products_yet">
	<div class="alert alert-info mt-4" role="alert">
		<strong>Heads up!</strong> To get started, <a href="<?php echo esc_url( wp_nonce_url( admin_url( 'admin.php?page=get_affiliate_link-products-add' ) ) ); ?>" class="alert-link">first add at least one product.</a>
	</div>
</div>


<div class="container" id="gal_price_table_has_products">
	<div class="row" id="gal-price-table-preview-container">

		<div class="col-12">
			<h3 class="pt-5 pb-3">Price Table Preview:</h3>
		</div>

		<div class="col-12" id="gal-price-table-live-preview">
			<table class="table">
				<thead>
				<tr>
					<th>Shop</th>
					<th>Product Title</th>
					<th style="text-align: right;">Current Price</th>
				</tr>
				</thead>
				<tbody class="gal-price-table">
				</tbody>
			</table>
		</div>
	</div>

	<div class="row pt-2" id="gal-price-table-source-code-container">
		<div class="col-12">
			<h3 class="pt-5 pb-3">Copy this code to your blog post:</h3>

			<textarea
					id="gal-price-table-source-code"
					readonly
					rows="7"
					style="min-width: 100%">
			</textarea>

			<div class="float-right">
				<button class="btn btn-primary action btn-lg btn-clipboard-copy" data-clipboard-target="#gal-price-table-source-code">
					<span class="dashicons dashicons-clipboard"></span> Copy to clipboard
				</button>
			</div>

		</div>
	</div>

	<div class="row pt-5">
		<div class="col-12">
			<h3>I want the following products in this table:</h3>

			<div class="card-deck" id="available_products"></div>
		</div>
	</div>

</div>



<script type="text/javascript">

	var activeProducts = [];

	var tablePreviewContainer = jQuery('#gal-price-table-preview-container');
	var tableLivePreview = jQuery('#gal-price-table-live-preview');
	var tableSourceCodeContainer = jQuery('#gal-price-table-source-code-container');


	function onToggleCheckbox(element, event) {
		event.preventDefault();

		doToggleCheckbox(element);

		updateProductDisplay();
	}


	function doToggleCheckbox(element) {
		var affiliateAccountId = element.dataset.affiliateAccountId;
		var merchantName = element.dataset.merchantName;
		var merchantLogo = element.dataset.merchantLogo;
		var productId = element.dataset.productId;
		var link = element.dataset.link;
		var productName = element.dataset.productName;

		var key = affiliateAccountId + '-' + merchantName + '-' + productId;
		var labelText = jQuery('#label_text_'+  element.id);

		activeProducts = activeProducts
			.filter(function(item) {
				return item.key !== key;
			})
		;

		if (false === element.checked) {
			// change button wording for UX reasons
			labelText.text('Select');

			// change Bootstrap card styling for UX reasons
			jQuery(element).closest('.card').removeClass('card-outline-success');
			jQuery(element).closest('.btn').removeClass('btn-success').addClass('btn-primary');

			return false;
		}

		// change button wording for UX reasons
		labelText.text("Selected");

		// change Bootstrap card styling for UX reasons
		jQuery(element).closest('.card').addClass('card-outline-success');
		jQuery(element).closest('.btn').addClass('btn-success').removeClass('btn-primary');

		var singlePrice = '<span class="gal-single-price" ' +
			'data-gal-affiliate-account="' + affiliateAccountId + '" ' +
			'data-gal-merchant="' + merchantName + '" ' +
			'data-gal-product="' + productId + '" ' +
			'data-gal-link="' + link + '" ' +
			'data-gal-link-text="__PRICE__">(Click for Latest Price)</span>';

		activeProducts.push({
			key: key,
			merchant: function() {
				return '<img src="' + merchantLogo + '" alt="' + merchantName + '">';
			},
			product: function() {
				return productName;
			},
			priceDisplay: singlePrice
		});

		return true;
	}
	

	function updateProductDisplay() {

		var tableBody = jQuery('.gal-price-table');

		tableBody.empty();

		activeProducts
			.map(function(element, index, array) {

				var tableRow = jQuery('<tr/>');

				tableRow
					.append(function() {
						return "<td style='padding: 4px; margin: 1px;'>" + element.merchant() + "</td>";
					})
					.append(function() {
						return '<td valign="middle">' + element.product() + '</td>';
					})
					.append(function() {
						return '<td valign="middle" style="text-align: right;">' + element.priceDisplay + '</td>';
					})
				;

				tableBody.append(tableRow);
			});

		var tableSourceCode = jQuery('#gal-price-table-source-code');
		tableSourceCode.empty();

		if (activeProducts.length === 0) {
			tablePreviewContainer.hide();
			tableSourceCodeContainer.hide();
		} else {
			tablePreviewContainer.show();
			tableSourceCodeContainer.show();
		}

		var table = tableLivePreview.htmlClean().html();
		tableSourceCode.val(table);
	}





	// this gets written out dynamically by PHP. Confusing...
	var available_products = <?php echo wp_json_encode( $product_data ); ?>;



	jQuery( document ).ready( function ( e ) {

		jQuery('#gal_price_table_has_products').show();
		jQuery('#gal_price_table_no_products_yet').hide();

	    if (available_products.length === 0) {
	        // display error
			jQuery('#gal_price_table_has_products').hide();
			jQuery('#gal_price_table_no_products_yet').show();

			return false;
		}

		updateProductDisplay();

		var availableProductsSelector = jQuery('#available_products');

		available_products
			.map(function(currentValue) {

				getProductData(
					currentValue.merchant_name,
					currentValue.affiliate_account_id,
					currentValue.product_id
				)
					.done(function(data, textStatus, jqXHR) {

						var galView = data.data[0].gal_view;

						var label = createProductLabel(galView);

						var id = galView.merchant_name + '_' + galView.id;

						var merchantLogo =  galView.merchant_logo || "https://placeholdit.imgix.net/~text?txtsize=16&txt=Logo%20unavailable&w=250&h=50";

						var b = '' +
'<div class="col-lg-4 col-md-6 col-sm-12">' +
'    <div class="card">' +
'        <img' +
'            class="card-img-top"' +
'            src="' + getImageUrl(galView) + '"' +
'            alt="' + galView.name + '">' +
'        <div class="card-block">' +
'            <h5 class="card-title">' + galView.name + '</h5>' +
'            <p class="card-text">' + galView.description.toString().trunc(150) + '</p>' +
'        </div>' +
'        <div class="card-footer text-center">' +
'            <div class="btn-group" data-toggle="buttons">' +
'                <label' +
'                    class="btn btn-lg btn-primary"' +
'                    for="selected_products_AmazonUk_B01GAGVIE4"' +
'                    aria-pressed="false">' +
'                        <input' +
'                            type="checkbox"' +
'                            name="selected_products" ' +
'                            id="selected_products_' + id + '" ' +
'                            value="' + galView.id + '" ' +
'                            data-affiliate-account-id="' + currentValue.affiliate_account_id + '" ' +
'                            data-merchant-name="' + currentValue.merchant_name + '" ' +
'                            data-product-id="' + currentValue.product_id + '" ' +
'                            data-link="' + currentValue.path+ '" ' +
'                            data-product-name="' + galView.name + '" ' +
'                            data-merchant-logo="' + merchantLogo + '" ' +
'                            autocomplete="off" ' +
'                            onchange="onToggleCheckbox(this, event);" /> ' +
'                        <span id="label_text_selected_products_' + id + '"">Select</span>' +
'                </label>' +
'            </div>' +
'        </div>' +
'    </div>' +
'</div>';

						availableProductsSelector.append(b);

					})
					.fail(function(jqXHR, textStatus, errorThrown) {
						console.log("lookup err", jqXHR, textStatus, errorThrown);
					});
			});
	});

	function getProductData(merchantName, affiliateAccountId, productId) {
		var url = buildProductLookUpUrl(merchantName, affiliateAccountId, productId);

		return jQuery
			.ajax({
				url: url,
				type: "GET",
				contentType: "application/json"
			});
	}

	function getImageUrl(galView) {
		return galView.image_url
			? galView.image_url
			: "https://placeholdit.imgix.net/~text?txtsize=33&txt=Preview%20unavailable&w=318&h=180";
	}

	function createProductLabel(galView,) {

		var checkbox = jQuery('<input/>', {
			type: "checkbox",
			name: "selected_products",
			id: "selected_products_" + galView.id,
			value: galView.id
		});


		var label = document.createElement('label');

		label.htmlFor = "selected_products_" + galView.id;
		label.innerHTML = '';

		return label;
	}


	String.prototype.trunc = String.prototype.trunc ||
		function(n){
			return (this.length > n) ? this.substr(0, n-1) + '&hellip;' : this;
		};

	jQuery.fn.htmlClean = function() {
		this.contents().filter(function() {
			if (this.nodeType != 3) {
				jQuery(this).htmlClean();
				return false;
			}
			else {
				this.textContent = jQuery.trim(this.textContent);
				return !/\S/.test(this.nodeValue);
			}
		}).remove();
		return this;
	};


</script>
